@@ -9,6 +9,21 @@ pub enum FaitheError {
     ProcessNotFound,
     /// No module with selected name were found.
     ModuleNotFound,
+    /// Failed to find selected pattern.
+    PatternNotFound,
+    /// Protection that cannot be represented with internal type.
+    #[cfg(all(windows, not(feature = "no-std")))]
+    UnknownProtection(u32),
+    /// String is not a valid UTF-8/UTF-16 sequence.
+    InvalidString,
+    /// Pattern is not an ASCII sequence.
+    NonAsciiPattern,
+    /// Supplied string cannot be parsed as a pattern of given type.
+    InvalidPattern,
+    /// Length of mask is not equal to the length of the pattern.
+    PatternMaskMismatch,
+    /// Tried to resolve function pointer twice.
+    AlreadyResolved,
 }
 
 pub(crate) type Result<T> = core::result::Result<T, FaitheError>;
@@ -30,4 +45,3 @@ cfg_if::cfg_if! {
         }
     }
 }
-
