@@ -8,10 +8,10 @@ pub trait PatternSearcher {
     type Iter: Iterator<Item = Self::Output>;
 
     /// Finds an iterator over all occurences of the pattern.
-    fn find_all_patterns(&self, pat: Pattern) -> crate::Result<Self::Iter>;
+    fn find_all(&self, pat: Pattern) -> crate::Result<Self::Iter>;
 
     /// Returns first occurence of the pattern if present.
-    fn find_first_pattern(&self, pat: Pattern) -> crate::Result<Option<Self::Output>> {
-        Ok(self.find_all_patterns(pat)?.next())
+    fn find_first(&self, pat: Pattern) -> crate::Result<Option<Self::Output>> {
+        Ok(self.find_all(pat)?.next())
     }
 }
